@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.112_02';
+our $VERSION = '0.113_01';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Dec 13 16:32:20 2018 GMT
+# on Sat Dec 22 15:02:03 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1714,7 +1714,7 @@ __PACKAGE__->status( add => 24946, iridium => '-', 'Iridium 33', 'Tumbling' );
 __PACKAGE__->status( add => 24947, iridium => 'D', 'Iridium 27', 'Decayed 2002-02-01' );
 __PACKAGE__->status( add => 24948, iridium => '-', 'Iridium 28', 'Tumbling' );
 __PACKAGE__->status( add => 24949, iridium => 'D', 'Iridium 30', 'Decayed 2017-09-28' );
-__PACKAGE__->status( add => 24950, iridium => '-', 'Iridium 31', 'Tumbling' );
+__PACKAGE__->status( add => 24950, iridium => 'D', 'Iridium 31', 'Decayed 2018-12-20' );
 __PACKAGE__->status( add => 24965, iridium => 'D', 'Iridium 19', 'Decayed 2018-04-07' );
 __PACKAGE__->status( add => 24966, iridium => '-', 'Iridium 35', 'Tumbling' );
 __PACKAGE__->status( add => 24967, iridium => '-', 'Iridium 36', 'Tumbling' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 8
 #       Spare [S]: 5
-#    Tumbling [-]: 35
-#     Decayed [D]: 49
+#    Tumbling [-]: 34
+#     Decayed [D]: 50
 
 1;
 
